@@ -195,12 +195,12 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
 
     m_extension = new BrowserExtension(this, "ak_extension");
 
-    connect(m_view, TQT_SIGNAL(setWindowCaption(const TQString&)), this, TQT_SIGNAL(setWindowCaption(const TQString&)));
-    connect(m_view, TQT_SIGNAL(setStatusBarText(const TQString&)), this, TQT_SIGNAL(setStatusBarText(const TQString&)));
-    connect(m_view, TQT_SIGNAL(setProgress(int)), m_extension, TQT_SIGNAL(loadingProgress(int)));
-    connect(m_view, TQT_SIGNAL(signalCanceled(const TQString&)), this, TQT_SIGNAL(canceled(const TQString&)));
-    connect(m_view, TQT_SIGNAL(signalStarted(TDEIO::Job*)), this, TQT_SIGNAL(started(TDEIO::Job*)));
-    connect(m_view, TQT_SIGNAL(signalCompleted()), this, TQT_SIGNAL(completed()));
+    connect(m_view, TQ_SIGNAL(setWindowCaption(const TQString&)), this, TQ_SIGNAL(setWindowCaption(const TQString&)));
+    connect(m_view, TQ_SIGNAL(setStatusBarText(const TQString&)), this, TQ_SIGNAL(setStatusBarText(const TQString&)));
+    connect(m_view, TQ_SIGNAL(setProgress(int)), m_extension, TQ_SIGNAL(loadingProgress(int)));
+    connect(m_view, TQ_SIGNAL(signalCanceled(const TQString&)), this, TQ_SIGNAL(canceled(const TQString&)));
+    connect(m_view, TQ_SIGNAL(signalStarted(TDEIO::Job*)), this, TQ_SIGNAL(started(TDEIO::Job*)));
+    connect(m_view, TQ_SIGNAL(signalCompleted()), this, TQ_SIGNAL(completed()));
 
     // notify the part that this is our internal widget
     setWidget(m_view);
@@ -209,7 +209,7 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
     TrayIcon::setInstance(trayIcon);
     m_actionManager->initTrayIcon(trayIcon);
 
-    connect(trayIcon, TQT_SIGNAL(showPart()), this, TQT_SIGNAL(showPart()));
+    connect(trayIcon, TQ_SIGNAL(showPart()), this, TQ_SIGNAL(showPart()));
 
     if ( isTrayIconEnabled() )
     {
@@ -219,15 +219,15 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
     else
         NotificationManager::self()->setWidget(getMainWindow(), instance());
 
-    connect( trayIcon, TQT_SIGNAL(quitSelected()),
-            kapp, TQT_SLOT(quit())) ;
+    connect( trayIcon, TQ_SIGNAL(quitSelected()),
+            kapp, TQ_SLOT(quit())) ;
 
-    connect( m_view, TQT_SIGNAL(signalUnreadCountChanged(int)), trayIcon, TQT_SLOT(slotSetUnread(int)) );
+    connect( m_view, TQ_SIGNAL(signalUnreadCountChanged(int)), trayIcon, TQ_SLOT(slotSetUnread(int)) );
 
-    connect(kapp, TQT_SIGNAL(shutDown()), this, TQT_SLOT(slotOnShutdown()));
+    connect(kapp, TQ_SIGNAL(shutDown()), this, TQ_SLOT(slotOnShutdown()));
 
     m_autosaveTimer = new TQTimer(this);
-    connect(m_autosaveTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotSaveFeedList()));
+    connect(m_autosaveTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotSaveFeedList()));
     m_autosaveTimer->start(5*60*1000); // 5 minutes
 
     setXMLFile("akregator_part.rc", true);
@@ -782,10 +782,10 @@ void Part::showOptions()
 
     TDEConfigDialog* dialog = new ConfigDialog( m_view, "settings", Settings::self() );
 
-    connect( dialog, TQT_SIGNAL(settingsChanged()),
-             this, TQT_SLOT(slotSettingsChanged()) );
-    connect( dialog, TQT_SIGNAL(settingsChanged()),
-             TrayIcon::getInstance(), TQT_SLOT(settingsChanged()) );
+    connect( dialog, TQ_SIGNAL(settingsChanged()),
+             this, TQ_SLOT(slotSettingsChanged()) );
+    connect( dialog, TQ_SIGNAL(settingsChanged()),
+             TrayIcon::getInstance(), TQ_SLOT(settingsChanged()) );
 
     dialog->show();
 }
