@@ -17,7 +17,7 @@ namespace Backend
 
 class SettingsAdvanced : public SettingsAdvancedBase
 {
-    Q_OBJECT
+    TQ_OBJECT
     
 
     public:
