@@ -36,7 +36,7 @@
 #include <tdelocale.h>
 #include <kdebug.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 AppearanceConfigurationPage::AppearanceConfigurationPage( TQWidget * parent, const char * name )
     : TDECModule( parent, name )
@@ -44,7 +44,7 @@ AppearanceConfigurationPage::AppearanceConfigurationPage( TQWidget * parent, con
   TQVBoxLayout* lay = new TQVBoxLayout( this );
   mWidget = new Kleo::AppearanceConfigWidget( this );
   lay->addWidget( mWidget );
-  connect( mWidget, TQT_SIGNAL( changed() ), this, TQT_SLOT( slotChanged() ) );
+  connect( mWidget, TQ_SIGNAL( changed() ), this, TQ_SLOT( slotChanged() ) );
 
 #ifndef HAVE_UNBROKEN_KCMULTIDIALOG
   load();
@@ -70,7 +70,7 @@ void AppearanceConfigurationPage::defaults()
 
 extern "C"
 {
-  KDE_EXPORT TDECModule *create_kleopatra_config_appear( TQWidget *parent, const char * )
+  TDE_EXPORT TDECModule *create_kleopatra_config_appear( TQWidget *parent, const char * )
   {
     AppearanceConfigurationPage *page =
       new AppearanceConfigurationPage( parent, "kleopatra_config_appear" );
