@@ -34,7 +34,7 @@
 
 #include <tdecmodule.h>
 #include <kleo/cryptoconfig.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class TQCheckBox;
 class TQTimeEdit;
@@ -50,7 +50,7 @@ namespace Kleo {
  * The user can configure LDAP servers in this page, to be used for listing/fetching
  * remote certificates in kleopatra.
  */
-class KDE_EXPORT DirectoryServicesConfigurationPage : public TDECModule {
+class TDE_EXPORT DirectoryServicesConfigurationPage : public TDECModule {
   TQ_OBJECT
   
 public:
