@@ -54,7 +54,7 @@
 #include <tqpair.h>
 #include <tqstringlist.h>
 #include <tqstring.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 
 class TDEConfigBase;
@@ -450,7 +450,7 @@ private:
 /*!
     \brief This class provides C++ access to the CRYPTPLUG API.
 */
-class KDE_EXPORT CryptPlugWrapper : public Kleo::CryptoBackend::Protocol {
+class TDE_EXPORT CryptPlugWrapper : public Kleo::CryptoBackend::Protocol {
 public:
     static TQString errorIdToText( int errId, bool & isPassphraseError );
 
