@@ -34,7 +34,7 @@
 #define __KLEO_PROGRESSBAR_H__
 
 #include <tqprogressbar.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 class TQTimer;
 
 namespace Kleo {
@@ -42,7 +42,7 @@ namespace Kleo {
   /**
      @short A TQProgressBar with self-powered busy indicator
   */
-  class KDE_EXPORT ProgressBar : public TQProgressBar {
+  class TDE_EXPORT ProgressBar : public TQProgressBar {
     TQ_OBJECT
   
   public:
