@@ -30,7 +30,7 @@
 #include <tdeabc/addresseelist.h>
 #include <klibloader.h>
 #include <kxmlguiclient.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #define KAB_XXPORT_PLUGIN_VERSION 1
 
@@ -44,7 +44,7 @@ class TDEApplication;
   @see: K_EXPORT_COMPONENT_FACTORY()
  */
 #define K_EXPORT_KADDRESSBOOK_XXFILTER_CATALOG( libname, XXPortClass, catalog ) \
- class KDE_NO_EXPORT localXXPortFactory : public KAB::XXPortFactory { \
+ class TDE_NO_EXPORT localXXPortFactory : public KAB::XXPortFactory { \
 	KAB::XXPort *xxportObject( TDEABC::AddressBook *ab, TQWidget *parent, const char *name ) \
 	 { const char *cat = catalog; \
 	   if (cat) TDEGlobal::locale()->insertCatalogue(cat); \
@@ -65,7 +65,7 @@ class TDEApplication;
 
 namespace KAB {
 
-class KDE_EXPORT XXPort : public TQObject, virtual public KXMLGUIClient
+class TDE_EXPORT XXPort : public TQObject, virtual public KXMLGUIClient
 {
   TQ_OBJECT
   
