@@ -95,7 +95,7 @@ void Daemon::initialise()
 {
 	if (!mInstance)
 		mInstance = new Daemon();
-	connect(AlarmCalendar::activeCalendar(), TQT_SIGNAL(calendarSaved(AlarmCalendar*)), mInstance, TQT_SLOT(slotCalendarSaved(AlarmCalendar*)));
+	connect(AlarmCalendar::activeCalendar(), TQ_SIGNAL(calendarSaved(AlarmCalendar*)), mInstance, TQ_SLOT(slotCalendarSaved(AlarmCalendar*)));
 }
 
 /******************************************************************************
@@ -111,10 +111,10 @@ void Daemon::createDcopHandler()
 	mRunning = isRunning(false);
 
 	mStatusTimerInterval = Preferences::daemonTrayCheckInterval();
-	Preferences::connect(TQT_SIGNAL(preferencesChanged()), mInstance, TQT_SLOT(slotPreferencesChanged()));
+	Preferences::connect(TQ_SIGNAL(preferencesChanged()), mInstance, TQ_SLOT(slotPreferencesChanged()));
 
 	mStatusTimer = new TQTimer(mInstance);
-	connect(mStatusTimer, TQT_SIGNAL(timeout()), mInstance, TQT_SLOT(timerCheckIfRunning()));
+	connect(mStatusTimer, TQ_SIGNAL(timeout()), mInstance, TQ_SLOT(timerCheckIfRunning()));
 	mStatusTimer->start(mStatusTimerInterval * 1000);  // check regularly if daemon is running
 }
 
@@ -145,7 +145,7 @@ bool Daemon::start()
 			kdDebug(5950) << "Daemon::start(): Alarm daemon started" << endl;
 			mStartTimeout = 5000/startCheckInterval + 1;    // check daemon status for 5 seconds before giving up
 			mStartTimer = new TQTimer(mInstance);
-			connect(mStartTimer, TQT_SIGNAL(timeout()), mInstance, TQT_SLOT(checkIfStarted()));
+			connect(mStartTimer, TQ_SIGNAL(timeout()), mInstance, TQ_SLOT(checkIfStarted()));
 			mStartTimer->start(startCheckInterval);
 			mInstance->checkIfStarted();
 			return true;
@@ -201,7 +201,7 @@ bool Daemon::registerWith(bool reregister)
 		return false;
 	}
 	mRegisterTimer = new TQTimer(mInstance);
-	connect(mRegisterTimer, TQT_SIGNAL(timeout()), mInstance, TQT_SLOT(registerTimerExpired()));
+	connect(mRegisterTimer, TQ_SIGNAL(timeout()), mInstance, TQ_SLOT(registerTimerExpired()));
 	mRegisterTimer->start(REGISTER_TIMEOUT * 1000);     // wait for the reply
 	return true;
 }
@@ -327,7 +327,7 @@ void Daemon::updateRegisteredStatus(bool timeout)
 				// The daemon has newly been detected as registered with DCOP.
 				// Wait for a short time to ensure that it is ready for DCOP calls.
 				mStatus = RUNNING;
-				TQTimer::singleShot(startCheckInterval, mInstance, TQT_SLOT(slotStarted()));
+				TQTimer::singleShot(startCheckInterval, mInstance, TQ_SLOT(slotStarted()));
 				break;
 			case RUNNING:
 				if (timeout)
@@ -569,8 +569,8 @@ void Daemon::slotPreferencesChanged()
 AlarmEnableAction* Daemon::createAlarmEnableAction(TDEActionCollection* actions, const char* name)
 {
 	AlarmEnableAction* a = new AlarmEnableAction(0, actions, name);
-	connect(a, TQT_SIGNAL(userClicked(bool)), mInstance, TQT_SLOT(setAlarmsEnabled(bool)));
-	connect(mInstance, TQT_SIGNAL(daemonRunning(bool)), a, TQT_SLOT(setCheckedActual(bool)));
+	connect(a, TQ_SIGNAL(userClicked(bool)), mInstance, TQ_SLOT(setAlarmsEnabled(bool)));
+	connect(mInstance, TQ_SIGNAL(daemonRunning(bool)), a, TQ_SLOT(setCheckedActual(bool)));
 	return a;
 }
 
