@@ -211,7 +211,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 	mTabs->addTab(mainPageBox, i18n("&Alarm"));
 	mMainPageIndex = 0;
 	PageFrame* mainPage = new PageFrame(mainPageBox);
-	connect(mainPage, TQT_SIGNAL(shown()), TQT_SLOT(slotShowMainPage()));
+	connect(mainPage, TQ_SIGNAL(shown()), TQ_SLOT(slotShowMainPage()));
 	TQVBoxLayout* topLayout = new TQVBoxLayout(mainPage, 0, spacingHint());
 
 	// Recurrence tab
@@ -220,15 +220,15 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 	mTabs->addTab(recurTab, TQString());
 	mRecurPageIndex = 1;
 	mRecurrenceEdit = new RecurrenceEdit(readOnly, recurTab, "recurPage");
-	connect(mRecurrenceEdit, TQT_SIGNAL(shown()), TQT_SLOT(slotShowRecurrenceEdit()));
-	connect(mRecurrenceEdit, TQT_SIGNAL(typeChanged(int)), TQT_SLOT(slotRecurTypeChange(int)));
-	connect(mRecurrenceEdit, TQT_SIGNAL(frequencyChanged()), TQT_SLOT(slotRecurFrequencyChange()));
-	connect(mRecurrenceEdit, TQT_SIGNAL(repeatNeedsInitialisation()), TQT_SLOT(slotSetSubRepetition()));
+	connect(mRecurrenceEdit, TQ_SIGNAL(shown()), TQ_SLOT(slotShowRecurrenceEdit()));
+	connect(mRecurrenceEdit, TQ_SIGNAL(typeChanged(int)), TQ_SLOT(slotRecurTypeChange(int)));
+	connect(mRecurrenceEdit, TQ_SIGNAL(frequencyChanged()), TQ_SLOT(slotRecurFrequencyChange()));
+	connect(mRecurrenceEdit, TQ_SIGNAL(repeatNeedsInitialisation()), TQ_SLOT(slotSetSubRepetition()));
 
 	// Alarm action
 
 	mActionGroup = new ButtonGroup(i18n("Action"), mainPage, "actionGroup");
-	connect(mActionGroup, TQT_SIGNAL(buttonSet(int)), TQT_SLOT(slotAlarmTypeChanged(int)));
+	connect(mActionGroup, TQ_SIGNAL(buttonSet(int)), TQ_SLOT(slotAlarmTypeChanged(int)));
 	topLayout->addWidget(mActionGroup, 1);
 	TQBoxLayout* layout = new TQVBoxLayout(mActionGroup, marginHint(), spacingHint());
 	layout->addSpacing(fontMetrics().lineSpacing()/2);
@@ -273,7 +273,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 	layout->addWidget(mEmailFrame);
 
 	// Deferred date/time: visible only for a deferred recurring event.
-	mDeferGroup = new TQGroupBox(1, Qt::Vertical, i18n("Deferred Alarm"), mainPage, "deferGroup");
+	mDeferGroup = new TQGroupBox(1, TQt::Vertical, i18n("Deferred Alarm"), mainPage, "deferGroup");
 	topLayout->addWidget(mDeferGroup);
 	TQLabel* label = new TQLabel(i18n("Deferred to:"), mDeferGroup);
 	label->setFixedSize(label->sizeHint());
@@ -281,7 +281,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 
 	mDeferChangeButton = new TQPushButton(i18n("C&hange..."), mDeferGroup);
 	mDeferChangeButton->setFixedSize(mDeferChangeButton->sizeHint());
-	connect(mDeferChangeButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotEditDeferral()));
+	connect(mDeferChangeButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotEditDeferral()));
 	TQWhatsThis::add(mDeferChangeButton, i18n("Change the alarm's deferred time, or cancel the deferral"));
 	mDeferGroup->addSpace(0);
 
@@ -291,7 +291,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 	if (mTemplate)
 	{
 		mTemplateTimeGroup = new ButtonGroup(i18n("Time"), mainPage, "templateGroup");
-		connect(mTemplateTimeGroup, TQT_SIGNAL(buttonSet(int)), TQT_SLOT(slotTemplateTimeType(int)));
+		connect(mTemplateTimeGroup, TQ_SIGNAL(buttonSet(int)), TQ_SLOT(slotTemplateTimeType(int)));
 		layout->addWidget(mTemplateTimeGroup);
 		grid = new TQGridLayout(mTemplateTimeGroup, 2, 2, marginHint(), spacingHint());
 		grid->addRowSpacing(0, fontMetrics().lineSpacing()/2);
@@ -355,7 +355,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 	else
 	{
 		mTimeWidget = new AlarmTimeWidget(i18n("Time"), AlarmTimeWidget::AT_TIME, mainPage, "timeGroup");
-		connect(mTimeWidget, TQT_SIGNAL(anyTimeToggled(bool)), TQT_SLOT(slotAnyTimeToggled(bool)));
+		connect(mTimeWidget, TQ_SIGNAL(anyTimeToggled(bool)), TQ_SLOT(slotAnyTimeToggled(bool)));
 		topLayout->addWidget(mTimeWidget);
 	}
 
@@ -489,7 +489,7 @@ void EditAlarmDlg::initCommand(TQWidget* parent)
 
 	mCmdTypeScript = new CheckBox(i18n_p_EnterScript(), mCommandFrame);
 	mCmdTypeScript->setFixedSize(mCmdTypeScript->sizeHint());
-	connect(mCmdTypeScript, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotCmdScriptToggled(bool)));
+	connect(mCmdTypeScript, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotCmdScriptToggled(bool)));
 	TQWhatsThis::add(mCmdTypeScript, i18n("Check to enter the contents of a script instead of a shell command line"));
 	frameLayout->addWidget(mCmdTypeScript, 0, TQt::AlignAuto);
 
@@ -595,7 +595,7 @@ void EditAlarmDlg::initEmail(TQWidget* parent)
 	mEmailAddressButton = new TQPushButton(mEmailFrame);
 	mEmailAddressButton->setPixmap(SmallIcon("contents"));
 	mEmailAddressButton->setFixedSize(mEmailAddressButton->sizeHint());
-	connect(mEmailAddressButton, TQT_SIGNAL(clicked()), TQT_SLOT(openAddressBook()));
+	connect(mEmailAddressButton, TQ_SIGNAL(clicked()), TQ_SLOT(openAddressBook()));
 	TQToolTip::add(mEmailAddressButton, i18n("Open address book"));
 	TQWhatsThis::add(mEmailAddressButton, i18n("Select email addresses from your address book."));
 	grid->addWidget(mEmailAddressButton, 1, 2);
@@ -635,12 +635,12 @@ list->setGeometry(rect.left() - 50, rect.top(), rect.width(), rect.height());
 	grid->setColStretch(1, 1);
 
 	mEmailAddAttachButton = new TQPushButton(i18n("Add..."), mEmailFrame);
-	connect(mEmailAddAttachButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotAddAttachment()));
+	connect(mEmailAddAttachButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotAddAttachment()));
 	TQWhatsThis::add(mEmailAddAttachButton, i18n("Add an attachment to the email."));
 	grid->addWidget(mEmailAddAttachButton, 0, 2);
 
 	mEmailRemoveButton = new TQPushButton(i18n("Remo&ve"), mEmailFrame);
-	connect(mEmailRemoveButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotRemoveAttachment()));
+	connect(mEmailRemoveButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotRemoveAttachment()));
 	TQWhatsThis::add(mEmailRemoveButton, i18n("Remove the highlighted attachment from the email."));
 	grid->addWidget(mEmailRemoveButton, 1, 2);
 
