@@ -747,7 +747,7 @@ bool readConfigWindowSize(const char* window, TQSize& result)
 {
 	TDEConfig* config = TDEGlobal::config();
 	config->setGroup(TQString::fromLatin1(window));
-	TQWidget* desktop = TQT_TQWIDGET(TDEApplication::desktop());
+	TQWidget* desktop = TDEApplication::desktop();
 	TQSize s = TQSize(config->readNumEntry(TQString::fromLatin1("Width %1").arg(desktop->width()), 0),
 	                config->readNumEntry(TQString::fromLatin1("Height %1").arg(desktop->height()), 0));
 	if (s.isEmpty())
@@ -764,7 +764,7 @@ void writeConfigWindowSize(const char* window, const TQSize& size)
 {
 	TDEConfig* config = TDEGlobal::config();
 	config->setGroup(TQString::fromLatin1(window));
-	TQWidget* desktop = TQT_TQWIDGET(TDEApplication::desktop());
+	TQWidget* desktop = TDEApplication::desktop();
 	config->writeEntry(TQString::fromLatin1("Width %1").arg(desktop->width()), size.width());
 	config->writeEntry(TQString::fromLatin1("Height %1").arg(desktop->height()), size.height());
 	config->sync();
