@@ -220,10 +220,10 @@ MobileGui::MobileGui( CommandScheduler *scheduler, KandyPrefs *kprefs,
   setMobState( UNLOADED );
 
   // Setup signal handlers
-  connect( mScheduler, TQT_SIGNAL( commandProcessed( ATCommand * ) ),
-           TQT_SLOT( processResult( ATCommand * ) ) );
-  connect( mScheduler->modem(), TQT_SIGNAL( gotLine( const char * ) ),
-           TQT_SLOT( termAddOutput( const char * ) ) );
+  connect( mScheduler, TQ_SIGNAL( commandProcessed( ATCommand * ) ),
+           TQ_SLOT( processResult( ATCommand * ) ) );
+  connect( mScheduler->modem(), TQ_SIGNAL( gotLine( const char * ) ),
+           TQ_SLOT( termAddOutput( const char * ) ) );
 }
 
 
