@@ -53,11 +53,11 @@ public:
     enum Direction { Left, Right, Up, Down };
 
     KDGanttMinimizeSplitter( TQWidget* parent=0, const char* name=0 );
-    KDGanttMinimizeSplitter( Qt::Orientation, TQWidget* parent=0, const char* name=0 );
+    KDGanttMinimizeSplitter( TQt::Orientation, TQWidget* parent=0, const char* name=0 );
     ~KDGanttMinimizeSplitter();
 
-    virtual void setOrientation( Qt::Orientation );
-    Qt::Orientation orientation() const { return orient; }
+    virtual void setOrientation( TQt::Orientation );
+    TQt::Orientation orientation() const { return orient; }
 
     void setMinimizeDirection( Direction );
     Direction minimizeDirection() const;
@@ -106,19 +106,19 @@ private:
     void setG( TQWidget *w, int p, int s, bool isSplitter = FALSE );
 
     TQCOORD pick( const TQPoint &p ) const
-    { return orient == Qt::Horizontal ? p.x() : p.y(); }
+    { return orient == TQt::Horizontal ? p.x() : p.y(); }
     TQCOORD pick( const TQSize &s ) const
-    { return orient == Qt::Horizontal ? s.width() : s.height(); }
+    { return orient == TQt::Horizontal ? s.width() : s.height(); }
 
     TQCOORD trans( const TQPoint &p ) const
-    { return orient == Qt::Vertical ? p.x() : p.y(); }
+    { return orient == TQt::Vertical ? p.x() : p.y(); }
     TQCOORD trans( const TQSize &s ) const
-    { return orient == Qt::Vertical ? s.width() : s.height(); }
+    { return orient == TQt::Vertical ? s.width() : s.height(); }
 
     TQSplitterData *data;
 
 private:
-    Qt::Orientation orient;
+    TQt::Orientation orient;
     Direction _direction;
 #ifndef DOXYGEN_SKIP_INTERNAL
     friend class KDGanttSplitterHandle;
@@ -140,10 +140,10 @@ class KDGanttSplitterHandle : public TQWidget
     TQ_OBJECT
     
 public:
-    KDGanttSplitterHandle( Qt::Orientation o,
+    KDGanttSplitterHandle( TQt::Orientation o,
 		       KDGanttMinimizeSplitter *parent, const char* name=0 );
-    void setOrientation( Qt::Orientation o );
-    Qt::Orientation orientation() const { return orient; }
+    void setOrientation( TQt::Orientation o );
+    TQt::Orientation orientation() const { return orient; }
 
     bool opaque() const { return s->opaqueResize(); }
 
@@ -162,7 +162,7 @@ protected:
     void updateCursor( const TQPoint& p );
 
 private:
-    Qt::Orientation orient;
+    TQt::Orientation orient;
     bool opaq;
     int myId;
 
