@@ -52,8 +52,8 @@ xQGanttBarViewPort::xQGanttBarViewPort(KGanttItem* toplevelitem,
   _itemTextEdit->hide();
   _itemTextEdit->setFrame(false);
   
-  connect(_itemTextEdit, TQT_SIGNAL(returnPressed ()),
-	  this, TQT_SLOT(textEdited()));
+  connect(_itemTextEdit, TQ_SIGNAL(returnPressed ()),
+	  this, TQ_SLOT(textEdited()));
 
   _iconloader = new TDEIconLoader();
 
@@ -83,8 +83,8 @@ xQGanttBarViewPort::xQGanttBarViewPort(KGanttItem* toplevelitem,
 
   _cursor_lupe = new TQCursor( TQPixmap(lupe) );
  
-  connect(_toplevelitem, TQT_SIGNAL(changed(KGanttItem*, KGanttItem::Change)),
-	  this, TQT_SLOT(toplevelitemChanged(KGanttItem*, KGanttItem::Change)) );
+  connect(_toplevelitem, TQ_SIGNAL(changed(KGanttItem*, KGanttItem::Change)),
+	  this, TQ_SLOT(toplevelitemChanged(KGanttItem*, KGanttItem::Change)) );
 
   recalc(); adjustSize();
 
@@ -116,8 +116,8 @@ xQGanttBarViewPort::toolbar(TQMainWindow* mw)
  
 
   _toolbar->insertButton("ganttSelect.png", 0, 
-			 TQT_SIGNAL(clicked()),
-			 TQT_TQOBJECT(this), TQT_SLOT(setSelect()),
+			 TQ_SIGNAL(clicked()),
+			 this, TQ_SLOT(setSelect()),
 			 true, i18n("Select") );
 
   TDEPopupMenu *selectMenu = new TDEPopupMenu(_toolbar);
@@ -128,7 +128,7 @@ xQGanttBarViewPort::toolbar(TQMainWindow* mw)
   */
   TQPixmap pix = _iconloader->loadIcon("ganttSelecttask.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("ganttSelecttask.png not found !\n");
-  selectMenu->insertItem(pix, i18n("Select All"), TQT_TQOBJECT(this), TQT_SLOT(selectAll()) );  
+  selectMenu->insertItem(pix, i18n("Select All"), this, TQ_SLOT(selectAll()) );  
 
 
   /*
@@ -136,7 +136,7 @@ xQGanttBarViewPort::toolbar(TQMainWindow* mw)
   */
   pix = _iconloader->loadIcon("ganttUnselecttask", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("ganttUnselecttask.png not found !\n");
-  selectMenu->insertItem(pix, i18n("Unselect All"), TQT_TQOBJECT(this), TQT_SLOT(unselectAll()) );
+  selectMenu->insertItem(pix, i18n("Unselect All"), this, TQ_SLOT(unselectAll()) );
 
 
   TDEToolBarButton* b = _toolbar->getButton(0);
@@ -144,31 +144,31 @@ xQGanttBarViewPort::toolbar(TQMainWindow* mw)
 
 
   _toolbar->insertButton("viewmag.png", 1, 
-			 TQT_SIGNAL(clicked()),
-			 TQT_TQOBJECT(this), TQT_SLOT(setZoom()),
+			 TQ_SIGNAL(clicked()),
+			 this, TQ_SLOT(setZoom()),
 			 true, i18n("Zoom") );
   
   TDEPopupMenu* zoomMenu = new TDEPopupMenu(_toolbar);
  
   pix = _iconloader->loadIcon("viewmag.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("viewmag.png not found !\n");
-  zoomMenu->insertItem(pix, i18n("Zoom All"), TQT_TQOBJECT(this), TQT_SLOT(zoomAll()) );
+  zoomMenu->insertItem(pix, i18n("Zoom All"), this, TQ_SLOT(zoomAll()) );
   zoomMenu->insertSeparator();
 
   pix = _iconloader->loadIcon("viewmag+.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("viewmag+.png not found !\n");
-  zoomMenu->insertItem(pix, i18n("Zoom In +"), TQT_TQOBJECT(this), TQT_SLOT(zoomIn()) );
+  zoomMenu->insertItem(pix, i18n("Zoom In +"), this, TQ_SLOT(zoomIn()) );
 
   pix = _iconloader->loadIcon("viewmag-.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("viewmag-.png not found !\n");
-  zoomMenu->insertItem(pix, i18n("Zoom Out -"), TQT_TQOBJECT(this), TQT_SLOT(zoomOut()) );
+  zoomMenu->insertItem(pix, i18n("Zoom Out -"), this, TQ_SLOT(zoomOut()) );
   
   b = _toolbar->getButton(1);
   b->setDelayedPopup(zoomMenu);
 
   _toolbar->insertButton("move.png", 2, 
-			  TQT_SIGNAL(clicked()),
-			  TQT_TQOBJECT(this), TQT_SLOT(setMove()),
+			  TQ_SIGNAL(clicked()),
+			  this, TQ_SLOT(setMove()),
 			  true, i18n("Move") );
 
    return _toolbar;
@@ -191,17 +191,17 @@ xQGanttBarViewPort::initMenu()
 
   TQPixmap pix = _iconloader->loadIcon("ganttSelect.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("ganttSelect.png not found !\n");
-  _selectMenu->insertItem(pix, i18n("Select Mode"), this, TQT_SLOT(setSelect()));
+  _selectMenu->insertItem(pix, i18n("Select Mode"), this, TQ_SLOT(setSelect()));
 
   _selectMenu->insertSeparator();
 
   pix = _iconloader->loadIcon("ganttSelecttask.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("ganttSelecttask.png not found !\n");
-  _selectMenu->insertItem(pix, i18n("Select All"), this, TQT_SLOT(selectAll()) );  
+  _selectMenu->insertItem(pix, i18n("Select All"), this, TQ_SLOT(selectAll()) );  
 
   pix = _iconloader->loadIcon("ganttUnselecttask", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("ganttUnselecttask.png not found !\n");
-  _selectMenu->insertItem(pix, i18n("Unselect All"), this, TQT_SLOT(unselectAll()) );
+  _selectMenu->insertItem(pix, i18n("Unselect All"), this, TQ_SLOT(unselectAll()) );
   
   _menu->insertItem( i18n("Select"), _selectMenu);
 
@@ -214,32 +214,32 @@ xQGanttBarViewPort::initMenu()
 
   pix = _iconloader->loadIcon("viewmag.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("viewmag.png not found !\n");
-  _zoomMenu->insertItem(i18n("Zoom Mode"), this, TQT_SLOT(setZoom()) );
+  _zoomMenu->insertItem(i18n("Zoom Mode"), this, TQ_SLOT(setZoom()) );
 
   _zoomMenu->insertSeparator();
 
-  _zoomMenu->insertItem(pix, i18n("Zoom All"), this, TQT_SLOT(zoomAll()) );
+  _zoomMenu->insertItem(pix, i18n("Zoom All"), this, TQ_SLOT(zoomAll()) );
   _zoomMenu->insertSeparator();
 
   pix = _iconloader->loadIcon("viewmag+.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("viewmag+.png not found !\n");
-  _zoomMenu->insertItem(pix, i18n("Zoom In +"), this, TQT_SLOT(zoomIn()) );
+  _zoomMenu->insertItem(pix, i18n("Zoom In +"), this, TQ_SLOT(zoomIn()) );
 
   pix = _iconloader->loadIcon("viewmag-.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("viewmag-.png not found !\n");
-  _zoomMenu->insertItem(pix, i18n("Zoom Out -"), this, TQT_SLOT(zoomOut()) );
+  _zoomMenu->insertItem(pix, i18n("Zoom Out -"), this, TQ_SLOT(zoomOut()) );
 
   _menu->insertItem( "Zoom", _zoomMenu);
 
   pix = _iconloader->loadIcon("move.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("move.png not found !\n");
-  _menu->insertItem(pix, i18n("Move Mode"), this, TQT_SLOT(setMove()) );
+  _menu->insertItem(pix, i18n("Move Mode"), this, TQ_SLOT(setMove()) );
 
   _menu->insertSeparator();
 
   pix = _iconloader->loadIcon("configure.png", TDEIcon::Toolbar , 16 );
   if(pix.isNull()) printf("configure.png not found !\n");
-  _menu->insertItem(pix, i18n("Configure Gantt..."), _parent, TQT_SLOT(showConfig()));
+  _menu->insertItem(pix, i18n("Configure Gantt..."), _parent, TQ_SLOT(showConfig()));
 
 }
 
@@ -1017,8 +1017,8 @@ xQGanttBarViewPort::deleteSelectedItems()
 #ifdef _DEBUG_
     printf(" : %s \n", subitem->getText().latin1() );
 #endif
-    connect(subitem, TQT_SIGNAL(destroyed(KGanttItem*)),
-	    this, TQT_SLOT(itemDestroyed(KGanttItem*)));
+    connect(subitem, TQ_SIGNAL(destroyed(KGanttItem*)),
+	    this, TQ_SLOT(itemDestroyed(KGanttItem*)));
   }
 
   list.remove(_toplevelitem);
