@@ -782,11 +782,11 @@ void AccountDialog::makePopAccountPage()
     i18n("Encryption"), page2 );
   mPop.encryptionNone =
     new TQRadioButton( i18n("&None"), mPop.encryptionGroup );
-  mPop.encryptionSSL =
-    new TQRadioButton( i18n("Use &SSL for secure mail download"),
-    mPop.encryptionGroup );
   mPop.encryptionTLS =
-    new TQRadioButton( i18n("Use &TLS for secure mail download"),
+    new TQRadioButton( i18n("Use &StartTLS"),
+    mPop.encryptionGroup );
+  mPop.encryptionSSL =
+    new TQRadioButton( i18n("Enforce SSL/&TLS"),
     mPop.encryptionGroup );
   connect(mPop.encryptionGroup, TQ_SIGNAL(clicked(int)),
     TQ_SLOT(slotPopEncryptionChanged(int)));
@@ -1097,11 +1097,11 @@ void AccountDialog::makeImapAccountPage( bool connected )
     i18n("Encryption"), page2 );
   mImap.encryptionNone =
     new TQRadioButton( i18n("&None"), mImap.encryptionGroup );
-  mImap.encryptionSSL =
-    new TQRadioButton( i18n("Use &SSL for secure mail download"),
-    mImap.encryptionGroup );
   mImap.encryptionTLS =
-    new TQRadioButton( i18n("Use &TLS for secure mail download"),
+    new TQRadioButton( i18n("Use &StartTLS"),
+    mImap.encryptionGroup );
+  mImap.encryptionSSL =
+    new TQRadioButton( i18n("Enforce SSL/&TLS"),
     mImap.encryptionGroup );
   connect(mImap.encryptionGroup, TQ_SIGNAL(clicked(int)),
     TQ_SLOT(slotImapEncryptionChanged(int)));
@@ -1499,12 +1499,12 @@ void AccountDialog::slotPopEncryptionChanged(int id)
 {
   kdDebug(5006) << "slotPopEncryptionChanged( " << id << " )" << endl;
   // adjust port
-  if ( id == SSL || mPop.portEdit->text() == "995" )
-    mPop.portEdit->setText( ( id == SSL ) ? "995" : "110" );
+  if ( id == EnforceSSL || mPop.portEdit->text() == "995" )
+    mPop.portEdit->setText( ( id == EnforceSSL ) ? "995" : "110" );
 
   // switch supported auth methods
-  mCurCapa = ( id == TLS ) ? mCapaTLS
-                           : ( id == SSL ) ? mCapaSSL
+  mCurCapa = ( id == StartTLS ) ? mCapaTLS
+                           : ( id == EnforceSSL ) ? mCapaSSL
                                            : mCapaNormal;
   enablePopFeatures( mCurCapa );
   const TQButton *old = mPop.authGroup->selected();
@@ -1517,12 +1517,12 @@ void AccountDialog::slotImapEncryptionChanged(int id)
 {
   kdDebug(5006) << "slotImapEncryptionChanged( " << id << " )" << endl;
   // adjust port
-  if ( id == SSL || mImap.portEdit->text() == "993" )
-    mImap.portEdit->setText( ( id == SSL ) ? "993" : "143" );
+  if ( id == EnforceSSL || mImap.portEdit->text() == "993" )
+    mImap.portEdit->setText( ( id == EnforceSSL ) ? "993" : "143" );
 
   // switch supported auth methods
-  int authMethods = ( id == TLS ) ? mCapaTLS
-                                  : ( id == SSL ) ? mCapaSSL
+  int authMethods = ( id == StartTLS ) ? mCapaTLS
+                                  : ( id == EnforceSSL ) ? mCapaSSL
                                                   : mCapaNormal;
   enableImapAuthMethods( authMethods );
   TQButton *old = mImap.authGroup->selected();
