@@ -59,7 +59,7 @@ namespace KMail {
   class AttachmentStrategy;
 
   class ImapAccountBase : public KMail::NetworkAccount {
-    Q_OBJECT
+    TQ_OBJECT
   
   protected:
     ImapAccountBase( AccountManager * parent, const TQString & name, uint id );
