@@ -11,7 +11,7 @@
 #include <tdeio/job.h>
 #include "kmmsgbase.h" // for KMMsgStatus
 #include <mimelib/string.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <kservice.h>
 #include <tdetempfile.h>
 
@@ -46,7 +46,7 @@ namespace Kleo { class SpecialJob; }
 typedef TQMap<int,KMFolder*> KMMenuToFolder;
 typedef TQMap<partNode*, KMMessage*> PartNodeMessageMap;
 
-class KDE_EXPORT KMCommand : public TQObject
+class TDE_EXPORT KMCommand : public TQObject
 {
   TQ_OBJECT
   
@@ -160,7 +160,7 @@ private:
   TQValueList<TQGuardedPtr<KMFolder> > mFolders;
 };
 
-class KDE_EXPORT KMMailtoComposeCommand : public KMCommand
+class TDE_EXPORT KMMailtoComposeCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -175,7 +175,7 @@ private:
   KMMessage *mMessage;
 };
 
-class KDE_EXPORT KMMailtoReplyCommand : public KMCommand
+class TDE_EXPORT KMMailtoReplyCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -191,7 +191,7 @@ private:
   TQString mSelection;
 };
 
-class KDE_EXPORT KMMailtoForwardCommand : public KMCommand
+class TDE_EXPORT KMMailtoForwardCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -206,7 +206,7 @@ private:
   KURL mUrl;
 };
 
-class KDE_EXPORT KMMailtoAddAddrBookCommand : public KMCommand
+class TDE_EXPORT KMMailtoAddAddrBookCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -220,7 +220,7 @@ private:
   KURL mUrl;
 };
 
-class KDE_EXPORT KMAddBookmarksCommand : public KMCommand
+class TDE_EXPORT KMAddBookmarksCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -235,7 +235,7 @@ private:
 };
 
 
-class KDE_EXPORT KMMailtoOpenAddrBookCommand : public KMCommand
+class TDE_EXPORT KMMailtoOpenAddrBookCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -249,7 +249,7 @@ private:
   KURL mUrl;
 };
 
-class KDE_EXPORT KMUrlCopyCommand : public KMCommand
+class TDE_EXPORT KMUrlCopyCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -264,7 +264,7 @@ private:
   KMMainWidget *mMainWidget;
 };
 
-class KDE_EXPORT KMUrlOpenCommand : public KMCommand
+class TDE_EXPORT KMUrlOpenCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -279,7 +279,7 @@ private:
   KMReaderWin *mReaderWin;
 };
 
-class KDE_EXPORT KMUrlSaveCommand : public KMCommand
+class TDE_EXPORT KMUrlSaveCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -296,7 +296,7 @@ private:
   KURL mUrl;
 };
 
-class KDE_EXPORT KMEditMsgCommand : public KMCommand
+class TDE_EXPORT KMEditMsgCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -308,7 +308,7 @@ private:
   virtual Result execute();
 };
 
-class KDE_EXPORT KMUseTemplateCommand : public KMCommand
+class TDE_EXPORT KMUseTemplateCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -320,7 +320,7 @@ private:
   virtual Result execute();
 };
 
-class KDE_EXPORT KMShowMsgSrcCommand : public KMCommand
+class TDE_EXPORT KMShowMsgSrcCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -335,7 +335,7 @@ private:
   bool mMsgWasComplete;
 };
 
-class KDE_EXPORT KMSaveMsgCommand : public KMCommand
+class TDE_EXPORT KMSaveMsgCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -367,7 +367,7 @@ private:
   TDEIO::TransferJob *mJob;
 };
 
-class KDE_EXPORT KMOpenMsgCommand : public KMCommand
+class TDE_EXPORT KMOpenMsgCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -391,7 +391,7 @@ private:
   const TQString mEncoding;
 };
 
-class KDE_EXPORT KMSaveAttachmentsCommand : public KMCommand
+class TDE_EXPORT KMSaveAttachmentsCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -430,7 +430,7 @@ private:
   bool mEncoded;
 };
 
-class KDE_EXPORT KMReplyToCommand : public KMCommand
+class TDE_EXPORT KMReplyToCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -446,7 +446,7 @@ private:
   TQString mSelection;
 };
 
-class KDE_EXPORT KMNoQuoteReplyToCommand : public KMCommand
+class TDE_EXPORT KMNoQuoteReplyToCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -474,7 +474,7 @@ private:
   TQString mSelection;
 };
 
-class KDE_EXPORT KMReplyToAllCommand : public KMCommand
+class TDE_EXPORT KMReplyToAllCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -490,7 +490,7 @@ private:
   TQString mSelection;
 };
 
-class KDE_EXPORT KMReplyAuthorCommand : public KMCommand
+class TDE_EXPORT KMReplyAuthorCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -506,7 +506,7 @@ private:
   TQString mSelection;
 };
 
-class KDE_EXPORT KMForwardInlineCommand : public KMCommand
+class TDE_EXPORT KMForwardInlineCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -524,7 +524,7 @@ private:
   uint mIdentity;
 };
 
-class KDE_EXPORT KMForwardAttachedCommand : public KMCommand
+class TDE_EXPORT KMForwardAttachedCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -542,7 +542,7 @@ private:
   TQGuardedPtr<KMail::Composer> mWin;
 };
 
-class KDE_EXPORT KMForwardDigestCommand : public KMCommand
+class TDE_EXPORT KMForwardDigestCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -560,7 +560,7 @@ private:
   TQGuardedPtr<KMail::Composer> mWin;
 };
 
-class KDE_EXPORT KMRedirectCommand : public KMCommand
+class TDE_EXPORT KMRedirectCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -572,7 +572,7 @@ private:
   virtual Result execute();
 };
 
-class KDE_EXPORT KMCustomReplyToCommand : public KMCommand
+class TDE_EXPORT KMCustomReplyToCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -590,7 +590,7 @@ private:
   TQString mTemplate;
 };
 
-class KDE_EXPORT KMCustomReplyAllToCommand : public KMCommand
+class TDE_EXPORT KMCustomReplyAllToCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -608,7 +608,7 @@ private:
   TQString mTemplate;
 };
 
-class KDE_EXPORT KMCustomForwardCommand : public KMCommand
+class TDE_EXPORT KMCustomForwardCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -626,7 +626,7 @@ private:
   TQString mTemplate;
 };
 
-class KDE_EXPORT KMPrintCommand : public KMCommand
+class TDE_EXPORT KMPrintCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -654,7 +654,7 @@ private:
   TQString mEncoding;
 };
 
-class KDE_EXPORT KMSeStatusCommand : public KMCommand
+class TDE_EXPORT KMSeStatusCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -673,7 +673,7 @@ private:
   bool mToggle;
 };
 
-class KDE_EXPORT KMFilterCommand : public KMCommand
+class TDE_EXPORT KMFilterCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -689,7 +689,7 @@ private:
 };
 
 
-class KDE_EXPORT KMFilterActionCommand : public KMCommand
+class TDE_EXPORT KMFilterActionCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -706,7 +706,7 @@ private:
 };
 
 
-class KDE_EXPORT KMMetaFilterActionCommand : public TQObject
+class TDE_EXPORT KMMetaFilterActionCommand : public TQObject
 {
   TQ_OBJECT
   
@@ -724,7 +724,7 @@ private:
   KMMainWidget *mMainWidget;
 };
 
-class KDE_EXPORT FolderShortcutCommand : public TQObject
+class TDE_EXPORT FolderShortcutCommand : public TQObject
 {
   TQ_OBJECT
   
@@ -747,7 +747,7 @@ private:
 };
 
 
-class KDE_EXPORT KMMailingListFilterCommand : public KMCommand
+class TDE_EXPORT KMMailingListFilterCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -767,7 +767,7 @@ private:
       copied.
       Am empty KMMenuToFolder must be passed in. */
 
-class KDE_EXPORT KMMenuCommand : public KMCommand
+class TDE_EXPORT KMMenuCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -780,7 +780,7 @@ public:
     TQObject *receiver, KMMenuToFolder *aMenuToFolder, TQPopupMenu *menu );
 };
 
-class KDE_EXPORT KMCopyCommand : public KMMenuCommand
+class TDE_EXPORT KMCopyCommand : public KMMenuCommand
 {
   TQ_OBJECT
   
@@ -806,7 +806,7 @@ private:
 namespace KPIM {
   class ProgressItem;
 }
-class KDE_EXPORT KMMoveCommand : public KMMenuCommand
+class TDE_EXPORT KMMoveCommand : public KMMenuCommand
 {
   TQ_OBJECT
   
@@ -842,7 +842,7 @@ private:
   bool mCompleteWithAddedMsg;
 };
 
-class KDE_EXPORT KMDeleteMsgCommand : public KMMoveCommand
+class TDE_EXPORT KMDeleteMsgCommand : public KMMoveCommand
 {
   TQ_OBJECT
   
@@ -857,7 +857,7 @@ private:
 
 };
 
-class KDE_EXPORT KMUrlClickedCommand : public KMCommand
+class TDE_EXPORT KMUrlClickedCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -876,7 +876,7 @@ private:
   KMMainWidget *mMainWidget;
 };
 
-class KDE_EXPORT KMLoadPartsCommand : public KMCommand
+class TDE_EXPORT KMLoadPartsCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -902,7 +902,7 @@ private:
   PartNodeMessageMap mPartMap;
 };
 
-class KDE_EXPORT KMResendMessageCommand : public KMCommand
+class TDE_EXPORT KMResendMessageCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -914,7 +914,7 @@ private:
   virtual Result execute();
 };
 
-class KDE_EXPORT KMMailingListCommand : public KMCommand
+class TDE_EXPORT KMMailingListCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -930,7 +930,7 @@ protected:
   KMFolder *mFolder;
 };
 
-class KDE_EXPORT KMMailingListPostCommand : public KMMailingListCommand
+class TDE_EXPORT KMMailingListPostCommand : public KMMailingListCommand
 {
   TQ_OBJECT
   
@@ -940,7 +940,7 @@ protected:
   virtual KURL::List urls() const;
 };
 
-class KDE_EXPORT KMMailingListSubscribeCommand : public KMMailingListCommand
+class TDE_EXPORT KMMailingListSubscribeCommand : public KMMailingListCommand
 {
   TQ_OBJECT
   
@@ -950,7 +950,7 @@ protected:
   virtual KURL::List urls() const;
 };
 
-class KDE_EXPORT KMMailingListUnsubscribeCommand : public KMMailingListCommand
+class TDE_EXPORT KMMailingListUnsubscribeCommand : public KMMailingListCommand
 {
   TQ_OBJECT
   
@@ -960,7 +960,7 @@ protected:
   virtual KURL::List urls() const;
 };
 
-class KDE_EXPORT KMMailingListArchivesCommand : public KMMailingListCommand
+class TDE_EXPORT KMMailingListArchivesCommand : public KMMailingListCommand
 {
   TQ_OBJECT
   
@@ -970,7 +970,7 @@ protected:
   virtual KURL::List urls() const;
 };
 
-class KDE_EXPORT KMMailingListHelpCommand : public KMMailingListCommand
+class TDE_EXPORT KMMailingListHelpCommand : public KMMailingListCommand
 {
   TQ_OBJECT
   
@@ -980,7 +980,7 @@ protected:
   virtual KURL::List urls() const;
 };
 
-class KDE_EXPORT KMIMChatCommand : public KMCommand
+class TDE_EXPORT KMIMChatCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -1001,7 +1001,7 @@ private:
   KMMessage *mMessage;
 };
 
-class KDE_EXPORT KMHandleAttachmentCommand : public KMCommand
+class TDE_EXPORT KMHandleAttachmentCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -1088,7 +1088,7 @@ private:
 
 
 /** Base class for commands modifying attachements of existing messages. */
-class KDE_EXPORT AttachmentModifyCommand : public KMCommand
+class TDE_EXPORT AttachmentModifyCommand : public KMCommand
 {
   TQ_OBJECT
   
@@ -1116,7 +1116,7 @@ class KDE_EXPORT AttachmentModifyCommand : public KMCommand
     TQGuardedPtr<KMFolder> mFolder;
 };
 
-class KDE_EXPORT KMDeleteAttachmentCommand : public AttachmentModifyCommand
+class TDE_EXPORT KMDeleteAttachmentCommand : public AttachmentModifyCommand
 {
   TQ_OBJECT
   
@@ -1130,7 +1130,7 @@ class KDE_EXPORT KMDeleteAttachmentCommand : public AttachmentModifyCommand
 };
 
 
-class KDE_EXPORT KMEditAttachmentCommand : public AttachmentModifyCommand
+class TDE_EXPORT KMEditAttachmentCommand : public AttachmentModifyCommand
 {
   TQ_OBJECT
   
@@ -1149,7 +1149,7 @@ class KDE_EXPORT KMEditAttachmentCommand : public AttachmentModifyCommand
     KTempFile mTempFile;
 };
 
-class KDE_EXPORT CreateTodoCommand : public KMCommand
+class TDE_EXPORT CreateTodoCommand : public KMCommand
 {
   TQ_OBJECT
   
