@@ -68,7 +68,7 @@ namespace KMail {
  */
 class FolderDiaTab : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
    FolderDiaTab( TQWidget *parent=0, const char* name=0 )
@@ -110,7 +110,7 @@ signals:
  */
 class FolderDiaGeneralTab : public FolderDiaTab
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -162,7 +162,7 @@ private:
  */
 class FolderDiaTemplatesTab : public FolderDiaTab
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -197,7 +197,7 @@ private:
  */
 class KMFolderDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
