@@ -36,7 +36,7 @@
 
 class KMFolderIndex: public FolderStorage
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   //TODO:Have to get rid of this friend declaration and add necessary pure
   //virtuals to kmfolder.h so that KMMsgBase::parent() can be a plain KMFolder
