@@ -73,7 +73,7 @@ namespace KParts {
 */
 
 class KMReaderWin: public TQWidget, public KMail::Interface::Observer {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   friend void KMMimePartTree::itemClicked( TQListViewItem* item );
@@ -257,6 +257,7 @@ public:
   // Action to reply to a message
   // but action( "some_name" ) some name could be used instead.
   TDEToggleAction *toggleFixFontAction() { return mToggleFixFontAction; }
+  TDEToggleAction *toggleMimePartTreeAction() { return mToggleMimePartTreeAction; }
   TDEAction *mailToComposeAction() { return mMailToComposeAction; }
   TDEAction *mailToReplyAction() { return mMailToReplyAction; }
   TDEAction *mailToForwardAction() { return mMailToForwardAction; }
@@ -410,10 +411,13 @@ public slots:
   /** The user toggled the "Fixed Font" flag from the view menu. */
   void slotToggleFixedFont();
 
+  /** Show or hide the Mime Tree Viewer */
+  void slotToggleMimePartTree();
+
   /** Copy the selected text to the clipboard */
   void slotCopySelectedText();
 
-   void slotUrlClicked();
+  void slotUrlClicked();
 
   /** Operations on mailto: URLs. */
   void slotMailtoReply();
@@ -594,6 +598,7 @@ private:
   TQStringList mTempFiles;
   TQStringList mTempDirs;
   int mMimeTreeMode;
+  int mMimeTreeModeOverride;
   bool mMimeTreeAtBottom;
   TQValueList<int> mSplitterSizes;
   partNode* mRootNode;
@@ -606,6 +611,7 @@ private:
   TDEToggleAction *mHeaderOnlyAttachmentsAction;
   TDESelectAction *mSelectEncodingAction;
   TDEToggleAction *mToggleFixFontAction;
+  TDEToggleAction *mToggleMimePartTreeAction;
 
   KURL mHoveredUrl;
   KURL mClickedUrl;
