@@ -472,7 +472,7 @@ int main( int argc, char *argv[] )
               << "(" << option << ")"
               << endl;
 
-    startdate = TQDate::fromString( option, Qt::ISODate );
+    startdate = TQDate::fromString( option, TQt::ISODate );
     if ( !startdate.isValid() ) {
       cout << i18n( "Invalid Start Date Specified: %1" ).
         arg( option ).local8Bit().data()
@@ -497,7 +497,7 @@ int main( int argc, char *argv[] )
               << endl;
 
     if ( option.upper() != "FLOAT" ) {
-      starttime = TQTime::fromString( option, Qt::ISODate );
+      starttime = TQTime::fromString( option, TQt::ISODate );
       if ( !starttime.isValid() ) {
         cout << i18n( "Invalid Start Time Specified: %1" ).
           arg( option ).local8Bit().data()
@@ -527,7 +527,7 @@ int main( int argc, char *argv[] )
               << "(" << option << ")"
               << endl;
 
-    enddate = TQDate::fromString( option, Qt::ISODate );
+    enddate = TQDate::fromString( option, TQt::ISODate );
     if ( !enddate.isValid() ) {
       cout << i18n( "Invalid End Date Specified: %1" ).
         arg( option ).local8Bit().data()
@@ -579,7 +579,7 @@ int main( int argc, char *argv[] )
               << endl;
 
     if ( option.upper() != "FLOAT" ) {
-      endtime = TQTime::fromString( option, Qt::ISODate );
+      endtime = TQTime::fromString( option, TQt::ISODate );
       if ( !endtime.isValid() ) {
         cout << i18n( "Invalid End Time Specified: %1" ).
           arg( option ).local8Bit().data()
@@ -854,10 +854,10 @@ int main( int argc, char *argv[] )
 
   // Some more debug prints
   kdDebug() << "main | datetimestamp | StartDate="
-            << startdatetime.toString( Qt::TextDate )
+            << startdatetime.toString( TQt::TextDate )
             << endl;
   kdDebug() << "main | datetimestamp | EndDate="
-            << enddatetime.toString( Qt::TextDate )
+            << enddatetime.toString( TQt::TextDate )
             << endl;
 
   /***************************************************************************
