@@ -38,11 +38,11 @@
 #include <tqlabel.h>
 #include <tqlayout.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 extern "C"
 {
-  KDE_EXPORT TDECModule *create_kontactconfig( TQWidget *parent, const char * ) {
+  TDE_EXPORT TDECModule *create_kontactconfig( TQWidget *parent, const char * ) {
     return new KcmKontact( parent, "kcmkontact" );
   }
 }
