@@ -168,7 +168,7 @@ void KNoScrollListBox::mousePressEvent( TQMouseEvent *e )
 {
   TQListBox::mousePressEvent( e );
 
-  if ( e->button() == Qt::RightButton ) {
+  if ( e->button() == TQt::RightButton ) {
     emit rightClick();
   }
 }
@@ -405,13 +405,13 @@ MonthViewCell::MonthViewCell( KOMonthView *parent)
 
   updateConfig();
 
-  connect( mItemList, TQT_SIGNAL( doubleClicked( TQListBoxItem *) ),
-           TQT_SLOT( defaultAction( TQListBoxItem * ) ) );
-  connect( mItemList, TQT_SIGNAL( rightButtonPressed( TQListBoxItem *,
+  connect( mItemList, TQ_SIGNAL( doubleClicked( TQListBoxItem *) ),
+           TQ_SLOT( defaultAction( TQListBoxItem * ) ) );
+  connect( mItemList, TQ_SIGNAL( rightButtonPressed( TQListBoxItem *,
                                                   const TQPoint &) ),
-           TQT_SLOT( contextMenu( TQListBoxItem * ) ) );
-  connect( mItemList, TQT_SIGNAL( clicked( TQListBoxItem * ) ),
-           TQT_SLOT( select() ) );
+           TQ_SLOT( contextMenu( TQListBoxItem * ) ) );
+  connect( mItemList, TQ_SIGNAL( clicked( TQListBoxItem * ) ),
+           TQ_SLOT( select() ) );
 }
 
 void MonthViewCell::setDate( const TQDate &date )
@@ -861,10 +861,10 @@ KOMonthView::KOMonthView( Calendar *calendar, TQWidget *parent, const char *name
       mCells.insert( row * mDaysPerWeek + col, cell );
       dayLayout->addWidget( cell, row + 2, col );
 
-      connect( cell, TQT_SIGNAL(defaultAction(Incidence *)),
-               TQT_SLOT(defaultAction(Incidence *)) );
-      connect( cell, TQT_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDate &)),
-               TQT_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDate &)) );
+      connect( cell, TQ_SIGNAL(defaultAction(Incidence *)),
+               TQ_SLOT(defaultAction(Incidence *)) );
+      connect( cell, TQ_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDate &)),
+               TQ_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDate &)) );
     }
     dayLayout->setRowStretch( row + 2, 1 );
   }
