@@ -21,8 +21,8 @@
 #ifndef KCAL_KCALEXPORT_H
 #define KCAL_KCALEXPORT_H
 
-#include <tdepimmacros.h>
+#include <tdemacros.h>
 
-#define LIBKCAL_EXPORT KDE_EXPORT
+#define LIBKCAL_EXPORT TDE_EXPORT
 
 #endif
