@@ -55,7 +55,7 @@ Base2::encrypt( Block& block, const KeyIDList& recipients )
 
 
 int
-Base2::clearsign( Block& block, const char *passphrase )
+Base2::clearsign( Block& block, const TQString &passphrase )
 {
   return encsign( block, KeyIDList(), passphrase );
 }
@@ -63,16 +63,16 @@ Base2::clearsign( Block& block, const char *passphrase )
 
 int
 Base2::encsign( Block& block, const KeyIDList& recipients,
-                const char *passphrase )
+                const TQString &passphrase )
 {
   TQCString cmd;
   int exitStatus = 0;
 
-  if(!recipients.isEmpty() && passphrase != 0)
+  if (!recipients.isEmpty() && !passphrase.isEmpty())
     cmd = PGP2 " +batchmode +language=en +verbose=1 -seat";
   else if(!recipients.isEmpty())
     cmd = PGP2 " +batchmode +language=en +verbose=1 -eat";
-  else if(passphrase != 0)
+  else if (!passphrase.isEmpty())
     cmd = PGP2 " +batchmode +language=en +verbose=1 -sat";
   else
   {
@@ -80,7 +80,7 @@ Base2::encsign( Block& block, const KeyIDList& recipients,
     return OK;
   }
 
-  if(passphrase != 0)
+  if (!passphrase.isEmpty())
     cmd += addUserId();
 
   if(!recipients.isEmpty()) {
@@ -185,7 +185,7 @@ Base2::encsign( Block& block, const KeyIDList& recipients,
     }
   }
 #endif
-  if(passphrase != 0)
+  if (!passphrase.isEmpty())
   {
     if(error.find("Pass phrase is good") != -1)
     {
@@ -224,7 +224,7 @@ Base2::encsign( Block& block, const KeyIDList& recipients,
 
 
 int
-Base2::decrypt( Block& block, const char *passphrase )
+Base2::decrypt( Block& block, const TQString &passphrase )
 {
   int index, index2;
   int exitStatus = 0;
@@ -294,7 +294,7 @@ Base2::decrypt( Block& block, const char *passphrase )
       block.setRequiredUserId( error.mid(index, index2 - index) );
       //kdDebug(5100) << "Base: key needed is \"" << block.requiredUserId() << "\"!\n";
 
-      if((passphrase != 0) && (error.find("Bad pass phrase") != -1))
+      if ((!passphrase.isEmpty()) && (error.find("Bad pass phrase") != -1))
       {
         errMsg = i18n("Bad passphrase; could not decrypt.");
         kdDebug(5100) << "Base: passphrase is bad" << endl;
@@ -573,7 +573,7 @@ Base2::secretKeys( const TQStringList & patterns )
 
 
 int
-Base2::signKey(const KeyID& keyID, const char *passphrase)
+Base2::signKey(const KeyID& keyID, const TQString &passphrase)
 {
   TQCString cmd;
   int exitStatus = 0;
