@@ -25,7 +25,7 @@
 #include <sys/time.h>
 
 #include <vector>
-#include <tdepimmacros.h>
+#include <tdemacros.h>
 
 namespace GpgME {
 
@@ -36,7 +36,7 @@ namespace GpgME {
   // class Key
   //
 
-  class KDE_EXPORT Key {
+  class TDE_EXPORT Key {
     friend class Context;
   public:
     Key();
@@ -110,7 +110,7 @@ namespace GpgME {
   // class Subkey
   //
 
-  class KDE_EXPORT Subkey {
+  class TDE_EXPORT Subkey {
   public:
     Subkey( gpgme_key_t key=0, gpgme_sub_key_t subkey=0 );
     Subkey( gpgme_key_t key, unsigned int idx );
@@ -156,7 +156,7 @@ namespace GpgME {
   // class UserID
   //
 
-  class KDE_EXPORT UserID {
+  class TDE_EXPORT UserID {
   public:
     class Signature;
 
@@ -198,7 +198,7 @@ namespace GpgME {
   // class UserID::Signature
   //
 
-  class KDE_EXPORT UserID::Signature {
+  class TDE_EXPORT UserID::Signature {
   public:
     class Notation;
 
@@ -255,7 +255,7 @@ namespace GpgME {
   //
   //
 
-  class KDE_EXPORT UserID::Signature::Notation {
+  class TDE_EXPORT UserID::Signature::Notation {
   public:
     Notation( gpgme_key_t key=0, gpgme_user_id_t uid=0,
 	      gpgme_key_sig_t sig=0, gpgme_sig_notation_t nota=0 );
