@@ -29,14 +29,14 @@
 #include <vector>
 #include <iosfwd>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace GpgME {
 
   class Error;
   class Signature;
 
-  class KDE_EXPORT VerificationResult : public Result {
+  class TDE_EXPORT VerificationResult : public Result {
   public:
     VerificationResult( gpgme_ctx_t ctx=0, int error=0 );
     explicit VerificationResult( const Error & err );
@@ -55,9 +55,9 @@ namespace GpgME {
     Private * d;
   };
 
-  KDE_EXPORT std::ostream & operator<<( std::ostream & os, const VerificationResult & result );
+  TDE_EXPORT std::ostream & operator<<( std::ostream & os, const VerificationResult & result );
 
-  class KDE_EXPORT Signature {
+  class TDE_EXPORT Signature {
     friend class VerificationResult;
     Signature( VerificationResult::Private * parent, unsigned int index );
   public:
@@ -113,10 +113,10 @@ namespace GpgME {
     unsigned int idx;
   };
 
-  KDE_EXPORT std::ostream & operator<<( std::ostream & os, const Signature & sig );
-  KDE_EXPORT std::ostream & operator<<( std::ostream & os, Signature::Summary summary );
+  TDE_EXPORT std::ostream & operator<<( std::ostream & os, const Signature & sig );
+  TDE_EXPORT std::ostream & operator<<( std::ostream & os, Signature::Summary summary );
 
-  class KDE_EXPORT Signature::Notation {
+  class TDE_EXPORT Signature::Notation {
     friend class Signature;
     Notation( VerificationResult::Private * parent, unsigned int sindex, unsigned int nindex );
   public:
@@ -137,7 +137,7 @@ namespace GpgME {
     unsigned int nidx;
   };
 
-  KDE_EXPORT std::ostream & operator<<( std::ostream & os, const Signature::Notation & nota );
+  TDE_EXPORT std::ostream & operator<<( std::ostream & os, const Signature::Notation & nota );
 
 }
 
