@@ -23,13 +23,13 @@
 #define KPIM_CATEGORYEDITDIALOG_H
 
 #include <kdialogbase.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class KPimPrefs;
 
 namespace KPIM {
 
-class KDE_EXPORT CategoryEditDialog : public KDialogBase
+class TDE_EXPORT CategoryEditDialog : public KDialogBase
 {
     TQ_OBJECT
   
