@@ -144,13 +144,13 @@ TDEPopupMenu *KPixmapRegionSelectorWidget::createPopupMenu()
    popup->insertTitle(i18n("Image Operations"));
 
    TDEAction *action = new TDEAction(i18n("&Rotate Clockwise"), "object-rotate-right",
-                                0, TQT_TQOBJECT(this), TQT_SLOT(rotateClockwise()),
-                                TQT_TQOBJECT(popup), "rotateclockwise");
+                                0, this, TQ_SLOT(rotateClockwise()),
+                                popup, "rotateclockwise");
    action->plug(popup);
 
    action = new TDEAction(i18n("Rotate &Counterclockwise"), "object-rotate-left",
-                                0, TQT_TQOBJECT(this), TQT_SLOT(rotateCounterclockwise()),
-                                TQT_TQOBJECT(popup), "rotatecounterclockwise");
+                                0, this, TQ_SLOT(rotateCounterclockwise()),
+                                popup, "rotatecounterclockwise");
    action->plug(popup);
 
 /*
@@ -218,7 +218,7 @@ bool KPixmapRegionSelectorWidget::eventFilter(TQObject *obj, TQEvent *ev)
       TQMouseEvent *mev= (TQMouseEvent *)(ev);
       //kdDebug() << TQString("click at  %1,%2").arg( mev->x() ).arg( mev->y() ) << endl;
 
-      if ( mev->button() == Qt::RightButton )
+      if ( mev->button() == TQt::RightButton )
       {
          TDEPopupMenu *popup = createPopupMenu( );
          popup->exec( mev->globalPos() );
