@@ -34,7 +34,7 @@
 
 #include <tqstring.h>
 
-#include <tdepimmacros.h>
+#include <tdemacros.h>
 
 /** @short A TQRegExp (TQt3.x) with a replace() method.
 
@@ -76,7 +76,7 @@
     @see TQRegExp
 */
 
-class KDE_EXPORT KRegExp3 : public TQRegExp
+class TDE_EXPORT KRegExp3 : public TQRegExp
 {
 public:
   KRegExp3()
