@@ -27,7 +27,7 @@
 #include "tqglobal.h"
 #include "time.h"
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 /**
  * TDEPIM classes for drag and drop of mails
@@ -44,7 +44,7 @@
 
 namespace KPIM {
 
-class KDE_EXPORT MailSummary 
+class TDE_EXPORT MailSummary 
 {
 public:
     MailSummary( TQ_UINT32 serialNumber, TQString messageId, TQString subject, 
@@ -83,7 +83,7 @@ private:
 typedef TQValueList<MailSummary> MailList;
 
 // Object for the drag object to call-back for message fulltext
-class KDE_EXPORT MailTextSource {
+class TDE_EXPORT MailTextSource {
 public:
     MailTextSource() {}
     virtual ~MailTextSource() {}
@@ -92,7 +92,7 @@ public:
 };
 
 // Drag and drop object for mails
-class KDE_EXPORT MailListDrag : public TQStoredDrag
+class TDE_EXPORT MailListDrag : public TQStoredDrag
 {
 public:
     // Takes ownership of "src" and deletes it when done
