@@ -19,7 +19,7 @@
 
 #include "resource.h"
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <tderesources/configwidget.h>
 
 class TQLineEdit;
@@ -37,7 +37,7 @@ class CalDavSaveConfig;
 /**
  * Configuration widget for CalDAV resource.
  */
-class KDE_EXPORT ResourceCalDavConfig : public KRES::ConfigWidget
+class TDE_EXPORT ResourceCalDavConfig : public KRES::ConfigWidget
 {
     TQ_OBJECT
   
