@@ -36,7 +36,7 @@
 #define KCALDAV_AUTOWIDGETS_H
 
 #include <tqwidget.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace KCal {
 
@@ -47,7 +47,7 @@ class ResourceCached;
 
   @see ResourceCached
 */
-class KDE_EXPORT CalDavReloadConfig : public TQWidget
+class TDE_EXPORT CalDavReloadConfig : public TQWidget
 {
   TQ_OBJECT
   
@@ -74,7 +74,7 @@ class KDE_EXPORT CalDavReloadConfig : public TQWidget
 
   @see ResourceCached
 */
-class KDE_EXPORT CalDavSaveConfig : public TQWidget
+class TDE_EXPORT CalDavSaveConfig : public TQWidget
 {
     TQ_OBJECT
   
