@@ -35,7 +35,7 @@
 #define KCARDDAV_AUTOWIDGETS_H
 
 #include <tqwidget.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace TDEABC {
 
@@ -46,7 +46,7 @@ class ResourceCached;
 
   @see ResourceCached
 */
-class KDE_EXPORT CardDavReloadConfig : public TQWidget
+class TDE_EXPORT CardDavReloadConfig : public TQWidget
 {
   TQ_OBJECT
   
@@ -73,7 +73,7 @@ class KDE_EXPORT CardDavReloadConfig : public TQWidget
 
   @see ResourceCached
 */
-class KDE_EXPORT CardDavSaveConfig : public TQWidget
+class TDE_EXPORT CardDavSaveConfig : public TQWidget
 {
     TQ_OBJECT
   
