@@ -23,11 +23,11 @@
 #define TDEABC_RESOURCEGROUPDAV_H
 
 #include "tdeabc_resourcegroupwarebase.h"
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace TDEABC {
 
-class KDE_EXPORT ResourceGroupDav : public ResourceGroupwareBase
+class TDE_EXPORT ResourceGroupDav : public ResourceGroupwareBase
 {
   TQ_OBJECT
   
