@@ -23,7 +23,7 @@
 #include "soap/groupwiseserver.h"
 
 #include <tderesources/configwidget.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #include <tqmap.h>
 
@@ -36,7 +36,7 @@ namespace TDEABC {
 
 class ResourceGroupwise;
 
-class KDE_EXPORT ResourceGroupwiseConfig : public KRES::ConfigWidget
+class TDE_EXPORT ResourceGroupwiseConfig : public KRES::ConfigWidget
 { 
   TQ_OBJECT
   
