@@ -23,7 +23,7 @@
 #define KCAL_RESOURCEGROUPWAREBASECONFIG_H
 
 #include <tderesources/configwidget.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class KPushButton;
 class KLineEdit;
@@ -44,7 +44,7 @@ class CacheSettingsDialog;
 
   @see KCalOpenGroupware
 */
-class KDE_EXPORT ResourceGroupwareBaseConfig : public KRES::ConfigWidget
+class TDE_EXPORT ResourceGroupwareBaseConfig : public KRES::ConfigWidget
 {
     TQ_OBJECT
   
