@@ -21,6 +21,7 @@
 
 #include <tqapplication.h>
 
+#include <tdeversion.h>
 #include <tdeabc/picture.h>
 #include <tdeconfig.h>
 #include <kdebug.h>
@@ -207,16 +208,16 @@ bool ResourceSlox::asyncLoad()
   kdDebug() << "REQUEST CONTACTS: \n" << doc.toString( 2 ) << endl;
 
   mDownloadJob = TDEIO::davPropFind( url, doc, "0", false );
-  connect( mDownloadJob, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           TQT_SLOT( slotResult( TDEIO::Job * ) ) );
-  connect( mDownloadJob, TQT_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
-           TQT_SLOT( slotProgress( TDEIO::Job *, unsigned long ) ) );
+  connect( mDownloadJob, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           TQ_SLOT( slotResult( TDEIO::Job * ) ) );
+  connect( mDownloadJob, TQ_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
+           TQ_SLOT( slotProgress( TDEIO::Job *, unsigned long ) ) );
 
   mDownloadProgress = KPIM::ProgressManager::instance()->createProgressItem(
       KPIM::ProgressManager::getUniqueID(), i18n("Downloading contacts") );
   connect( mDownloadProgress,
-           TQT_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
-           TQT_SLOT( cancelDownload() ) );
+           TQ_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
+           TQ_SLOT( cancelDownload() ) );
 
   mPrefs->setLastSync( TQDateTime::currentDateTime() );
 
@@ -401,7 +402,7 @@ void ResourceSlox::parseContactAttribute( const TQDomElement &e, Addressee &a )
     a.insertCustom( "KADDRESSBOOK", "X-SpousesName", text );
   } else if ( tag == fieldName( Anniversary ) ) {
     TQDateTime dt = WebdavHandler::sloxToTQDateTime( text );
-    a.insertCustom( "KADDRESSBOOK", "X-Anniversary", dt.toString( Qt::ISODate ) );
+    a.insertCustom( "KADDRESSBOOK", "X-Anniversary", dt.toString( TQt::ISODate ) );
   } else if ( tag == fieldName( Categories ) ) {
     a.setCategories( TQStringList::split( TQRegExp(",\\s*"), text ) );
   } else if ( type() == "ox" ) { // FIXME: Address reading is missing for SLOX
@@ -520,16 +521,16 @@ void ResourceSlox::uploadContacts()
   url.setPass( mPrefs->password() );
 
   mUploadJob = TDEIO::davPropPatch( url, doc, false );
-  connect( mUploadJob, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           TQT_SLOT( slotUploadResult( TDEIO::Job * ) ) );
-  connect( mUploadJob, TQT_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
-           TQT_SLOT( slotProgress( TDEIO::Job *, unsigned long ) ) );
+  connect( mUploadJob, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           TQ_SLOT( slotUploadResult( TDEIO::Job * ) ) );
+  connect( mUploadJob, TQ_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
+           TQ_SLOT( slotProgress( TDEIO::Job *, unsigned long ) ) );
 
   mUploadProgress = KPIM::ProgressManager::instance()->createProgressItem(
       KPIM::ProgressManager::getUniqueID(), i18n("Uploading contacts") );
   connect( mUploadProgress,
-           TQT_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
-           TQT_SLOT( cancelUpload() ) );
+           TQ_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
+           TQ_SLOT( cancelUpload() ) );
 }
 
 void ResourceSlox::createAddresseeFields( TQDomDocument &doc, TQDomElement &prop,
@@ -576,7 +577,7 @@ void ResourceSlox::createAddresseeFields( TQDomDocument &doc, TQDomElement &prop
     TQString anniversary = a.custom( "KADDRESSBOOK", "X-Anniversary" );
     if ( !anniversary.isEmpty() )
       WebdavHandler::addSloxElement( this, doc, prop, fieldName( Anniversary ),
-        WebdavHandler::qDateTimeToSlox( TQDateTime::fromString( anniversary, Qt::ISODate ).date() ) );
+        WebdavHandler::qDateTimeToSlox( TQDateTime::fromString( anniversary, TQt::ISODate ).date() ) );
     else
       WebdavHandler::addSloxElement( this, doc, prop, fieldName( Anniversary ) );
   }
